# rss_provider

This is the backend addon for [volto-rss-provider](https://github.com/collective/volto-rss-provider).

## Features

### Content Types

- The backend addon adds a `rss_feed` content type with `blocks` behavior enabled and two additional `max_title_length` and `max_description_length` fields in its schema.

## Installation

Install rss_provider with `pip`:

```shell
pip install rss_provider
```

And to create the Plone site:

```shell
make create_site
```

## Contribute

- [Issue Tracker](https://github.com/collective/rss-provider/issues)
- [Source Code](https://github.com/collective/rss-provider/)

## License

The project is licensed under the GPLv2.
